amachine.am_machine API documentation

# amachine.am_machine

View Source

     1from abc import ABC, abstractmethod
     2
     3from .am_causal_state import CausalState
     4from .am_transition import Transition
     5from .am_symbol import Symbol
     6
     7class Machine(ABC) :
     8
     9	@property
    10	@abstractmethod
    11	def get_states(self) -> list[CausalState]: ...
    12
    13	@property
    14	@abstractmethod
    15	def get_transitions(self) -> list[Transition]: ...
    16
    17	@property
    18	@abstractmethod
    19	def get_alphabet(self) -> list[Symbol]: ...

class Machine(abc.ABC): View Source

     8class Machine(ABC) :
     9
    10	@property
    11	@abstractmethod
    12	def get_states(self) -> list[CausalState]: ...
    13
    14	@property
    15	@abstractmethod
    16	def get_transitions(self) -> list[Transition]: ...
    17
    18	@property
    19	@abstractmethod
    20	def get_alphabet(self) -> list[Symbol]: ...

Helper class that provides a standard way to create an ABC using inheritance.

get_states: list[amachine.am_causal_state.CausalState] View Source

    10	@property
    11	@abstractmethod
    12	def get_states(self) -> list[CausalState]: ...

get_transitions: list[amachine.am_transition.Transition] View Source

    14	@property
    15	@abstractmethod
    16	def get_transitions(self) -> list[Transition]: ...

get_alphabet: list[amachine.am_symbol.Symbol] View Source

    18	@property
    19	@abstractmethod
    20	def get_alphabet(self) -> list[Symbol]: ...